==> certmanager-model-v1beta1-6.3.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/OrderSpecFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceFluent;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface OrderSpecFluent<A extends OrderSpecFluent<A>> extends Fluent<A>{
  public String getCommonName();
  public A withCommonName(String commonName);
  public Boolean hasCommonName();
  public A addToDnsNames(Integer index,String item);
  public A setToDnsNames(Integer index,String item);
  public A addToDnsNames(java.lang.String... items);
  public A addAllToDnsNames(Collection<String> items);
  public A removeFromDnsNames(java.lang.String... items);
  public A removeAllFromDnsNames(Collection<String> items);
  public List<String> getDnsNames();
  public String getDnsName(Integer index);
  public String getFirstDnsName();
  public String getLastDnsName();
  public String getMatchingDnsName(Predicate<String> predicate);
  public Boolean hasMatchingDnsName(Predicate<String> predicate);
  public A withDnsNames(List<String> dnsNames);
  public A withDnsNames(java.lang.String... dnsNames);
  public Boolean hasDnsNames();
  public Duration getDuration();
  public A withDuration(Duration duration);
  public Boolean hasDuration();
  public A addToIpAddresses(Integer index,String item);
  public A setToIpAddresses(Integer index,String item);
  public A addToIpAddresses(java.lang.String... items);
  public A addAllToIpAddresses(Collection<String> items);
  public A removeFromIpAddresses(java.lang.String... items);
  public A removeAllFromIpAddresses(Collection<String> items);
  public List<String> getIpAddresses();
  public String getIpAddress(Integer index);
  public String getFirstIpAddress();
  public String getLastIpAddress();
  public String getMatchingIpAddress(Predicate<String> predicate);
  public Boolean hasMatchingIpAddress(Predicate<String> predicate);
  public A withIpAddresses(List<String> ipAddresses);
  public A withIpAddresses(java.lang.String... ipAddresses);
  public Boolean hasIpAddresses();
  
  /**
   * This method has been deprecated, please use method buildIssuerRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getIssuerRef();
  public ObjectReference buildIssuerRef();
  public A withIssuerRef(ObjectReference issuerRef);
  public Boolean hasIssuerRef();
  public A withNewIssuerRef(String group,String kind,String name);
  public OrderSpecFluent.IssuerRefNested<A> withNewIssuerRef();
  public OrderSpecFluent.IssuerRefNested<A> withNewIssuerRefLike(ObjectReference item);
  public OrderSpecFluent.IssuerRefNested<A> editIssuerRef();
  public OrderSpecFluent.IssuerRefNested<A> editOrNewIssuerRef();
  public OrderSpecFluent.IssuerRefNested<A> editOrNewIssuerRefLike(ObjectReference item);
  public String getRequest();
  public A withRequest(String request);
  public Boolean hasRequest();
  public interface IssuerRefNested<N> extends Nested<N>,ObjectReferenceFluent<OrderSpecFluent.IssuerRefNested<N>>{
    public N and();
    public N endIssuerRef();
    
  }
  
}

==> certmanager-model-v1beta1-6.7.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/OrderSpecFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.ObjectReferenceFluent;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface OrderSpecFluent<A extends OrderSpecFluent<A>> extends Fluent<A>{
  public String getCommonName();
  public A withCommonName(String commonName);
  public Boolean hasCommonName();
  public A addToDnsNames(int index,String item);
  public A setToDnsNames(int index,String item);
  public A addToDnsNames(java.lang.String... items);
  public A addAllToDnsNames(Collection<String> items);
  public A removeFromDnsNames(java.lang.String... items);
  public A removeAllFromDnsNames(Collection<String> items);
  public List<String> getDnsNames();
  public String getDnsName(int index);
  public String getFirstDnsName();
  public String getLastDnsName();
  public String getMatchingDnsName(Predicate<String> predicate);
  public Boolean hasMatchingDnsName(Predicate<String> predicate);
  public A withDnsNames(List<String> dnsNames);
  public A withDnsNames(java.lang.String... dnsNames);
  public Boolean hasDnsNames();
  public Duration getDuration();
  public A withDuration(Duration duration);
  public Boolean hasDuration();
  public A addToIpAddresses(int index,String item);
  public A setToIpAddresses(int index,String item);
  public A addToIpAddresses(java.lang.String... items);
  public A addAllToIpAddresses(Collection<String> items);
  public A removeFromIpAddresses(java.lang.String... items);
  public A removeAllFromIpAddresses(Collection<String> items);
  public List<String> getIpAddresses();
  public String getIpAddress(int index);
  public String getFirstIpAddress();
  public String getLastIpAddress();
  public String getMatchingIpAddress(Predicate<String> predicate);
  public Boolean hasMatchingIpAddress(Predicate<String> predicate);
  public A withIpAddresses(List<String> ipAddresses);
  public A withIpAddresses(java.lang.String... ipAddresses);
  public Boolean hasIpAddresses();
  
  /**
   * This method has been deprecated, please use method buildIssuerRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getIssuerRef();
  public ObjectReference buildIssuerRef();
  public A withIssuerRef(ObjectReference issuerRef);
  public Boolean hasIssuerRef();
  public A withNewIssuerRef(String group,String kind,String name);
  public OrderSpecFluent.IssuerRefNested<A> withNewIssuerRef();
  public OrderSpecFluent.IssuerRefNested<A> withNewIssuerRefLike(ObjectReference item);
  public OrderSpecFluent.IssuerRefNested<A> editIssuerRef();
  public OrderSpecFluent.IssuerRefNested<A> editOrNewIssuerRef();
  public OrderSpecFluent.IssuerRefNested<A> editOrNewIssuerRefLike(ObjectReference item);
  public String getRequest();
  public A withRequest(String request);
  public Boolean hasRequest();
  public interface IssuerRefNested<N> extends Nested<N>,ObjectReferenceFluent<OrderSpecFluent.IssuerRefNested<N>>{
    public N and();
    public N endIssuerRef();
    
  }
  
}
